@@ -11,11 +11,12 @@ from typing import (
     runtime_checkable,
 )
 
-from fastapi import APIRouter, Request, Response
+from fastapi import APIRouter, HTTPException, Request, Response
 from fastapi.routing import APIRoute
 from pydantic import BaseModel
 
-from fastapi_resources.resources.base_resource import Resource
+from fastapi_resources.resources.sqlmodel.exceptions import NotFound
+from fastapi_resources.resources.types import ResourceProtocol
 from fastapi_resources.routers import decorators
 
 
@@ -27,7 +28,7 @@ class TUpdatePayload(BaseModel):
     pass
 
 
-TResource = TypeVar("TResource", bound=Resource)
+TResource = TypeVar("TResource", bound=ResourceProtocol)
 
 
 @runtime_checkable
@@ -95,6 +96,12 @@ class ResourceRouter(APIRouter, Generic[TResource]):
             "_update": {TUpdatePayload: self.get_update_model()},
         }
 
+    def api_route(self, *args, **kwargs):
+        try:
+            return super().api_route(*args, **kwargs)
+        except NotFound as e:
+            raise HTTPException(status_code=404, detail=str(e))
+
     def _patch_route_types(self):
         for method_name, replacements in self.method_replacements.items():
             method_instance = getattr(self, method_name, None)
@@ -209,11 +216,11 @@ class ResourceRouter(APIRouter, Generic[TResource]):
         return resource
 
     def get_resource_kwargs(self, request: Request):
-        return {}
+        return {"request": request}
 
     def build_response(
         self,
-        resource: Resource,
+        resource: TResource,
         rows: Union[BaseModel, List[BaseModel]],
         request: Request,
     ):
